==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QMediaAvailabilityControl_shell.h <==
#ifndef QMEDIAAVAILABILITYCONTROL_SHELL_H
#define QMEDIAAVAILABILITYCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediaavailabilitycontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmultimedia.h>
#include <QtJambi/RegistryAPI>


class QMediaAvailabilityControl_shell : public QMediaAvailabilityControl, public QtJambiShellInterface
{
public:
    QMediaAvailabilityControl_shell(QObject* parent0 = nullptr);
    ~QMediaAvailabilityControl_shell() override;

    QMultimedia::AvailabilityStatus availability() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaAvailabilityControl_access : public QMediaAvailabilityControl
{
    jint __qt_availability(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMEDIAAVAILABILITYCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QMediaAvailabilityControl_shell.h <==
#ifndef QMEDIAAVAILABILITYCONTROL_SHELL_H
#define QMEDIAAVAILABILITYCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediaavailabilitycontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmultimedia.h>
#include <QtJambi/RegistryAPI>


class QMediaAvailabilityControl_shell : public QMediaAvailabilityControl, public QtJambiShellInterface
{
public:
    QMediaAvailabilityControl_shell(QObject* parent0 = nullptr);
    ~QMediaAvailabilityControl_shell() override;

    QMultimedia::AvailabilityStatus availability() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaAvailabilityControl_access : public QMediaAvailabilityControl
{
    jint __qt_availability_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMEDIAAVAILABILITYCONTROL_SHELL_H
